==> qtify_0.0.3.tar.gz: qtify-0.0.3/translations/qtify_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="515"/>
        <source>Playlist</source>
        <translation type="unfinished">Spilleliste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>Artist</source>
        <translation type="unfinished">Artist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Rating</source>
        <translation type="unfinished">Rangering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Username</source>
        <translation type="unfinished">Brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Password</source>
        <translation type="unfinished">Passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="obsolete">Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Title</source>
        <translation type="unfinished">Tittel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="obsolete">Spill/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Ugyldig brukernavn eller passord, vennligst prøv igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Updating playlists...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Select playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qtify_0.1.0.tar.gz: qtify-0.1.0/translations/qtify_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="823"/>
        <source>Playlist</source>
        <translation type="unfinished">Spilleliste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Artist</source>
        <translation type="unfinished">Artist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="571"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Rating</source>
        <translation type="unfinished">Rangering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="831"/>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Username</source>
        <translation type="unfinished">Brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Password</source>
        <translation type="unfinished">Passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="obsolete">Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Title</source>
        <translation type="unfinished">Tittel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Play/Pause</source>
        <translation type="obsolete">Spill/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Ugyldig brukernavn eller passord, vennligst prøv igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Updating playlists...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Select playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Various artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>Tracks: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Remember</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="639"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="662"/>
        <source>#</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="826"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="834"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="839"/>
        <source>Albums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="842"/>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
